@@ -1,5 +1,6 @@
 import click
 from dnastack.client import *
+from dnastack.cli.auth import get_oauth_token
 
 
 @click.group()
@@ -11,11 +12,15 @@ def tables(ctx):
 @tables.command(name="list")
 @click.pass_context
 def list_tables(ctx):
+    oauth_token = get_oauth_token(ctx)
     try:
-        click.echo(dataconnect_client.list_tables(ctx.obj["data-connect-url"]))
-    except:
+        click.echo(
+            dataconnect_client.list_tables(ctx.obj["data-connect-url"], oauth_token)
+        )
+    except Exception as e:
         click.secho(
-            f"Unable to list tables from url [{ctx.obj['data-connect-url']}]", fg="red"
+            f"Unable to list tables from url [{ctx.obj['data-connect-url']}]: {e}",
+            fg="red",
         )
         sys.exit(1)
 
