@@ -42,7 +42,7 @@ def download(ctx, urls, output_dir, input_file, quiet):
 
             download_urls.append(url)
     try:
-        download_files(download_urls, output_dir)
+        download_files(download_urls, output_dir, quiet=quiet)
     except Exception as e:
         click.secho(str(e), fg="red")
         sys.exit(1)
