@@ -14,9 +14,19 @@ def list_tables(collections_url, collection_name):
 
 def query(collections_url, collection_name, query, format="json"):
     collection_query_url = f"{collections_url}/{collection_name}/data-connect/search"
-    results = req.post(collection_query_url, json={"query": query})
+
+    res = req.post(collection_query_url, json={"query": query})
+
+    results = res.json()
+
+    if not res.ok:
+        if "errors" in results:
+            error_msg = results["errors"][0]["title"]
+            raise Exception(error_msg)
+        raise Exception()
+
     if format == "csv":
-        return format_query_result_as_csv(results.json()["data"])
+        return format_query_result_as_csv(results["data"])
     else:
         # load and redump the json to allow for proper formatting
-        return json.dumps(results.json()["data"], indent=4)
+        return json.dumps(results["data"], indent=4)
