@@ -2,26 +2,24 @@ import os
 import unittest
 from click.testing import CliRunner
 import json
-from dnastack import __main__ as cli
+from dnastack import __main__ as dnastack_cli
+from .. import *
 
 
 class TestCliConfigCommand(unittest.TestCase):
     def setUp(self):
         self.runner = CliRunner()
-        self.data_connect_url = (
-            os.getenv("E2E_DATA_CONNECT_URI")
-            or "https://collection-service.publisher.dnastack.com/collection/library/search/"
-        )
+        self.data_connect_url = TEST_DATA_CONNECT_URI
 
     def test_cli_config_add_config_and_list(self):
         result = self.runner.invoke(
-            cli.dnastack, ["config", "set", "testKey", "testValue"]
+            dnastack_cli.dnastack, ["config", "set", "testKey", "testValue"]
         )
 
         self.assertEqual(result.exit_code, 1)
 
         self.runner.invoke(
-            cli.dnastack,
+            dnastack_cli.dnastack,
             [
                 "config",
                 "set",
@@ -30,7 +28,7 @@ class TestCliConfigCommand(unittest.TestCase):
             ],
         )
 
-        result = self.runner.invoke(cli.dnastack, ["config", "list"])
+        result = self.runner.invoke(dnastack_cli.dnastack, ["config", "list"])
 
         result_object = json.loads(result.output)
 
